==> tuia-news-center-api-0.0.44-xt4-20180627.033812-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/StealPacketDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/6/25.
 */
public class StealPacketDto implements Serializable {
    private Long id;

    private Long userId;

    private Long packetId;

    private Long stealUserId;

    private String stealName;

    private String stealHead;

    private Long stealAmount;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getPacketId() {
        return packetId;
    }

    public void setPacketId(Long packetId) {
        this.packetId = packetId;
    }

    public Long getStealUserId() {
        return stealUserId;
    }

    public void setStealUserId(Long stealUserId) {
        this.stealUserId = stealUserId;
    }

    public String getStealName() {
        return stealName;
    }

    public void setStealName(String stealName) {
        this.stealName = stealName == null ? null : stealName.trim();
    }

    public String getStealHead() {
        return stealHead;
    }

    public void setStealHead(String stealHead) {
        this.stealHead = stealHead == null ? null : stealHead.trim();
    }

    public Long getStealAmount() {
        return stealAmount;
    }

    public void setStealAmount(Long stealAmount) {
        this.stealAmount = stealAmount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-2.1.6.0-xt-20190617.040139-6-sources.jar: cn/com/duiba/tuia/news/center/dto/req/StealPacketDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/6/25.
 */
public class StealPacketDto implements Serializable {
    private Long id;

    private Long userId;

    private Long packetId;

    private Long stealUserId;

    private String stealName;

    private String stealHead;

    private Long stealAmount;

    private Date gmtCreate;

    private Date gmtModified;

    private Integer sign;

    public Integer getSign() {
        return sign;
    }

    public void setSign(Integer sign) {
        this.sign = sign;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getPacketId() {
        return packetId;
    }

    public void setPacketId(Long packetId) {
        this.packetId = packetId;
    }

    public Long getStealUserId() {
        return stealUserId;
    }

    public void setStealUserId(Long stealUserId) {
        this.stealUserId = stealUserId;
    }

    public String getStealName() {
        return stealName;
    }

    public void setStealName(String stealName) {
        this.stealName = stealName == null ? null : stealName.trim();
    }

    public String getStealHead() {
        return stealHead;
    }

    public void setStealHead(String stealHead) {
        this.stealHead = stealHead == null ? null : stealHead.trim();
    }

    public Long getStealAmount() {
        return stealAmount;
    }

    public void setStealAmount(Long stealAmount) {
        this.stealAmount = stealAmount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
